"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const fs = __importStar(require("fs"));
const klaw_sync_1 = __importDefault(require("klaw-sync"));
const path = __importStar(require("path"));
const interfaces_1 = require("./interfaces");
const parse_1 = require("./parse");
function genPrefix(first, relativePath) {
    const res = [];
    if (typeof first === 'string' && first.length > 0) {
        res.push(first);
    }
    res.push(...relativePath
        .split(path.sep)
        .filter(w => w.length > 0)
        .map(w => w.substr(0, w.length - 3))
        .filter(w => w.length > 0));
    return res;
}
function cleanObject(obj) {
    const res = {};
    Object.keys(obj).forEach(key => {
        const { prefix, body, description, scope } = obj[key];
        res[key] = {
            prefix, body, description, scope
        };
    });
    return res;
}
function generator(config) {
    const cog = Object.assign({}, interfaces_1.DEFAULT_CONFIG, config);
    const sourceRoot = path.resolve(process.cwd(), cog.sourceRoot);
    const allPaths = klaw_sync_1.default(sourceRoot, {
        nodir: true,
        traverseAll: true,
        filter: (item) => item.path.endsWith('.md')
    })
        .map(item => item.path);
    const res = {};
    allPaths.forEach(filePath => {
        const relativePath = path.relative(sourceRoot, filePath);
        const md = fs.readFileSync(filePath).toString('utf8');
        try {
            const item = parse_1.parse(md, filePath);
            const keys = genPrefix(cog.prefix, relativePath);
            item.prefix = keys.join(cog.separator);
            res[keys.join('_')] = item;
        }
        catch (err) {
            console.log(`>> File ${relativePath} parse error: ${chalk_1.default.red(err)}`);
        }
    });
    const successCount = Object.keys(res).length;
    console.log(`Find ${allPaths.length} markdowns, Success ${chalk_1.default.green(successCount + '')}, Error ${chalk_1.default.red((allPaths.length - successCount) + '')}`);
    return cleanObject(res);
}
exports.generator = generator;
