#!/usr/bin/env node
"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs = __importStar(require("fs"));
const meow_1 = __importDefault(require("meow"));
const path = __importStar(require("path"));
const generator_1 = require("./generator");
const interfaces_1 = require("./interfaces");
const cli = meow_1.default({
    help: `
  Usage
    vscode-snippet-generator

  Example
    vscode-snippet-generator -i CHANGELOG.md --same-file

  Options
    --sourceRoot      Source file root directory, default: src

    --outFile         Output file path, default: snippets.json

    --prefix          Unified prefix

    --separator       Multi-level directory separator, default: -

    --config          A filepath of your config script
                      Example of a config script: https://github.com/conventional-changelog/conventional-changelog-angular/blob/master/index.js
  `,
    flags: {
        sourceRoot: {
            type: 'string',
            default: 'src'
        },
        outFile: {
            type: 'string',
            default: 'snippets.json'
        },
        prefix: {
            type: 'string'
        },
        separator: {
            type: 'string',
            default: '-'
        },
        config: {
            type: 'string',
            default: 'snippet-config.json'
        }
    }
});
let configInFile;
try {
    const { config } = cli.flags;
    const configFile = path.resolve(process.cwd(), config);
    if (fs.existsSync(configFile)) {
        configInFile = require(configFile);
    }
}
catch (err) {
    console.error('Invalid config file', err);
    process.exit(1);
}
const options = Object.assign({}, interfaces_1.DEFAULT_CONFIG, cli.flags, configInFile);
const res = generator_1.generator(options);
const content = JSON.stringify(res, null, 2);
const saveFile = path.resolve(process.cwd(), options.outFile);
if (fs.existsSync(saveFile)) {
    fs.unlinkSync(saveFile);
}
fs.writeFileSync(saveFile, content);
